# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutDetailBillAttachment(UniversalBaseModel):
    """
    Attachment for a bill.
    """

    ftype: typing.Optional[str] = pydantic.Field(default=None)
    """
    File type.
    """

    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    File name.
    """

    file_descriptor: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="fileDescriptor"),
        pydantic.Field(alias="fileDescriptor", description="File descriptor."),
    ] = None
    furl: typing.Optional[str] = pydantic.Field(default=None)
    """
    File URL.
    """

    f_content: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="fContent"),
        pydantic.Field(alias="fContent", description="File content."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
