# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .bad_request_auth_response_error_v_2 import BadRequestAuthResponseErrorV2
    from .bad_request_capture_response_error_v_2 import BadRequestCaptureResponseErrorV2
    from .bad_request_refund_response_error_v_2 import BadRequestRefundResponseErrorV2
    from .bad_request_void_response_error_v_2 import BadRequestVoidResponseErrorV2
    from .declined_auth_response_error_v_2 import DeclinedAuthResponseErrorV2
    from .declined_capture_response_error_v_2 import DeclinedCaptureResponseErrorV2
    from .declined_refund_response_error_v_2 import DeclinedRefundResponseErrorV2
    from .declined_void_response_error_v_2 import DeclinedVoidResponseErrorV2
    from .internal_server_response_error_v_2 import InternalServerResponseErrorV2
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestAuthResponseErrorV2": ".bad_request_auth_response_error_v_2",
    "BadRequestCaptureResponseErrorV2": ".bad_request_capture_response_error_v_2",
    "BadRequestRefundResponseErrorV2": ".bad_request_refund_response_error_v_2",
    "BadRequestVoidResponseErrorV2": ".bad_request_void_response_error_v_2",
    "DeclinedAuthResponseErrorV2": ".declined_auth_response_error_v_2",
    "DeclinedCaptureResponseErrorV2": ".declined_capture_response_error_v_2",
    "DeclinedRefundResponseErrorV2": ".declined_refund_response_error_v_2",
    "DeclinedVoidResponseErrorV2": ".declined_void_response_error_v_2",
    "InternalServerResponseErrorV2": ".internal_server_response_error_v_2",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestAuthResponseErrorV2",
    "BadRequestCaptureResponseErrorV2",
    "BadRequestRefundResponseErrorV2",
    "BadRequestVoidResponseErrorV2",
    "DeclinedAuthResponseErrorV2",
    "DeclinedCaptureResponseErrorV2",
    "DeclinedRefundResponseErrorV2",
    "DeclinedVoidResponseErrorV2",
    "InternalServerResponseErrorV2",
]
