# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutMessageProperties(UniversalBaseModel):
    """
    Properties associated with a transfer message.
    """

    original_transfer_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="originalTransferStatus"),
        pydantic.Field(
            alias="originalTransferStatus", description="The original status of the transfer before the message."
        ),
    ] = None
    current_transfer_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="currentTransferStatus"),
        pydantic.Field(
            alias="currentTransferStatus", description="The current status of the transfer after the message."
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
