# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.is_enabled import IsEnabled


class AddPaymentMethodDomainRequestApplePay(UniversalBaseModel):
    """
    Apple Pay configuration information.
    """

    is_enabled: typing_extensions.Annotated[
        typing.Optional[IsEnabled], FieldMetadata(alias="isEnabled"), pydantic.Field(alias="isEnabled")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
