# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutSummary(UniversalBaseModel):
    """
    Summary information for outbound transfer queries.
    """

    total_pages: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalPages"),
        pydantic.Field(alias="totalPages", description="Number of pages in the response."),
    ] = None
    total_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalRecords"),
        pydantic.Field(alias="totalRecords", description="Number of records in the response."),
    ] = None
    page_size: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="pageSize"),
        pydantic.Field(alias="pageSize", description="Number of records per page."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
