# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutDetailEvent(UniversalBaseModel):
    """
    Event data for an outbound transfer detail.
    """

    trans_event: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="TransEvent"),
        pydantic.Field(alias="TransEvent", description="Description of the transaction event."),
    ] = None
    event_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EventData"),
        pydantic.Field(alias="EventData", description="Additional event data."),
    ] = None
    event_time: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EventTime"),
        pydantic.Field(alias="EventTime", description="Time the event occurred."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
