# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .v_2_bad_request_error import V2BadRequestError
    from .v_2_bad_request_error_detail import V2BadRequestErrorDetail
    from .v_2_declined_transaction_response_wrapper import V2DeclinedTransactionResponseWrapper
    from .v_2_internal_server_error import V2InternalServerError
    from .v_2_response_action import V2ResponseAction
    from .v_2_response_code import V2ResponseCode
    from .v_2_response_explanation import V2ResponseExplanation
    from .v_2_response_reason import V2ResponseReason
    from .v_2_transaction_detail_response_data import V2TransactionDetailResponseData
    from .v_2_transaction_details import V2TransactionDetails
    from .v_2_transaction_response_wrapper import V2TransactionResponseWrapper
_dynamic_imports: typing.Dict[str, str] = {
    "V2BadRequestError": ".v_2_bad_request_error",
    "V2BadRequestErrorDetail": ".v_2_bad_request_error_detail",
    "V2DeclinedTransactionResponseWrapper": ".v_2_declined_transaction_response_wrapper",
    "V2InternalServerError": ".v_2_internal_server_error",
    "V2ResponseAction": ".v_2_response_action",
    "V2ResponseCode": ".v_2_response_code",
    "V2ResponseExplanation": ".v_2_response_explanation",
    "V2ResponseReason": ".v_2_response_reason",
    "V2TransactionDetailResponseData": ".v_2_transaction_detail_response_data",
    "V2TransactionDetails": ".v_2_transaction_details",
    "V2TransactionResponseWrapper": ".v_2_transaction_response_wrapper",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "V2BadRequestError",
    "V2BadRequestErrorDetail",
    "V2DeclinedTransactionResponseWrapper",
    "V2InternalServerError",
    "V2ResponseAction",
    "V2ResponseCode",
    "V2ResponseExplanation",
    "V2ResponseReason",
    "V2TransactionDetailResponseData",
    "V2TransactionDetails",
    "V2TransactionResponseWrapper",
]
