# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutEventData(UniversalBaseModel):
    """
    Event data associated with an outbound transfer.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the event.
    """

    event_time: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="eventTime"),
        pydantic.Field(alias="eventTime", description="The time the event occurred."),
    ] = None
    ref_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="refData"),
        pydantic.Field(alias="refData", description="Reference data for the event."),
    ] = None
    extra_data: typing_extensions.Annotated[
        typing.Optional[typing.Any],
        FieldMetadata(alias="extraData"),
        pydantic.Field(
            alias="extraData", description="Additional event data, which may contain detailed transaction information."
        ),
    ] = None
    source: typing.Optional[str] = pydantic.Field(default=None)
    """
    The source of the event.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
