# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutBankAccount(UniversalBaseModel):
    """
    Bank account information for an outbound transfer.
    """

    account_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="accountNumber"),
        pydantic.Field(alias="accountNumber", description="The masked bank account number."),
    ] = None
    routing_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="routingNumber"),
        pydantic.Field(alias="routingNumber", description="The bank routing number."),
    ] = None
    bank_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="bankName"),
        pydantic.Field(alias="bankName", description="The bank name."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
