# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransactionDetailEvent(UniversalBaseModel):
    """
    Event associated with transaction processing
    """

    trans_event: typing_extensions.Annotated[str, FieldMetadata(alias="transEvent"), pydantic.Field(alias="transEvent")]
    event_data: typing_extensions.Annotated[str, FieldMetadata(alias="eventData"), pydantic.Field(alias="eventData")]
    event_time: typing_extensions.Annotated[str, FieldMetadata(alias="eventTime"), pydantic.Field(alias="eventTime")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
