# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.api_error import ApiError
from ..types.v_2_declined_transaction_response_wrapper import V2DeclinedTransactionResponseWrapper


class DeclinedVoidResponseErrorV2(ApiError):
    def __init__(
        self, body: V2DeclinedTransactionResponseWrapper, headers: typing.Optional[typing.Dict[str, str]] = None
    ):
        super().__init__(status_code=402, headers=headers, body=body)
