# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class StatBasicQueryRecord(UniversalBaseModel):
    stat_x: typing_extensions.Annotated[
        str, FieldMetadata(alias="statX"), pydantic.Field(alias="statX", description="Statistical grouping identifier")
    ]
    in_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inTransactions"),
        pydantic.Field(alias="inTransactions", description="Number of incoming transactions"),
    ]
    in_transactions_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inTransactionsVolume"),
        pydantic.Field(alias="inTransactionsVolume", description="Volume of incoming transactions"),
    ]
    in_wallet_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inWalletTransactions"),
        pydantic.Field(alias="inWalletTransactions", description="Number of incoming wallet transactions"),
    ]
    in_wallet_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inWalletVolume"),
        pydantic.Field(alias="inWalletVolume", description="Volume of incoming wallet transactions"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
