# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        V2BadRequestError,
        V2BadRequestErrorDetail,
        V2DeclinedTransactionResponseWrapper,
        V2InternalServerError,
        V2ResponseAction,
        V2ResponseCode,
        V2ResponseExplanation,
        V2ResponseReason,
        V2TransactionDetailResponseData,
        V2TransactionDetails,
        V2TransactionResponseWrapper,
    )
    from .errors import (
        BadRequestAuthResponseErrorV2,
        BadRequestCaptureResponseErrorV2,
        BadRequestRefundResponseErrorV2,
        BadRequestVoidResponseErrorV2,
        DeclinedAuthResponseErrorV2,
        DeclinedCaptureResponseErrorV2,
        DeclinedRefundResponseErrorV2,
        DeclinedVoidResponseErrorV2,
        InternalServerResponseErrorV2,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestAuthResponseErrorV2": ".errors",
    "BadRequestCaptureResponseErrorV2": ".errors",
    "BadRequestRefundResponseErrorV2": ".errors",
    "BadRequestVoidResponseErrorV2": ".errors",
    "DeclinedAuthResponseErrorV2": ".errors",
    "DeclinedCaptureResponseErrorV2": ".errors",
    "DeclinedRefundResponseErrorV2": ".errors",
    "DeclinedVoidResponseErrorV2": ".errors",
    "InternalServerResponseErrorV2": ".errors",
    "V2BadRequestError": ".types",
    "V2BadRequestErrorDetail": ".types",
    "V2DeclinedTransactionResponseWrapper": ".types",
    "V2InternalServerError": ".types",
    "V2ResponseAction": ".types",
    "V2ResponseCode": ".types",
    "V2ResponseExplanation": ".types",
    "V2ResponseReason": ".types",
    "V2TransactionDetailResponseData": ".types",
    "V2TransactionDetails": ".types",
    "V2TransactionResponseWrapper": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestAuthResponseErrorV2",
    "BadRequestCaptureResponseErrorV2",
    "BadRequestRefundResponseErrorV2",
    "BadRequestVoidResponseErrorV2",
    "DeclinedAuthResponseErrorV2",
    "DeclinedCaptureResponseErrorV2",
    "DeclinedRefundResponseErrorV2",
    "DeclinedVoidResponseErrorV2",
    "InternalServerResponseErrorV2",
    "V2BadRequestError",
    "V2BadRequestErrorDetail",
    "V2DeclinedTransactionResponseWrapper",
    "V2InternalServerError",
    "V2ResponseAction",
    "V2ResponseCode",
    "V2ResponseExplanation",
    "V2ResponseReason",
    "V2TransactionDetailResponseData",
    "V2TransactionDetails",
    "V2TransactionResponseWrapper",
]
