# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class NotificationLogSearchRequest(UniversalBaseModel):
    start_date: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="startDate"),
        pydantic.Field(alias="startDate", description="The start date for the search."),
    ]
    end_date: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="endDate"),
        pydantic.Field(alias="endDate", description="The end date for the search."),
    ]
    notification_event: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="notificationEvent"),
        pydantic.Field(alias="notificationEvent", description="The type of notification event to filter by."),
    ] = None
    succeeded: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates whether the notification was successful.
    """

    org_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="orgId"),
        pydantic.Field(alias="orgId", description="The ID of the organization to filter by."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="paypointId"),
        pydantic.Field(alias="paypointId", description="The ID of the paypoint to filter by."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
